"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IapAppEngineServiceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapAppEngineServiceIamBindingXCondition = IapAppEngineServiceIamBindingXCondition

@typing_extensions.final
class IapAppEngineServiceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    service: builtins.str
    @property
    def condition(self) -> global___IapAppEngineServiceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        condition: global___IapAppEngineServiceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service"]) -> None: ...

global___IapAppEngineServiceIamBinding = IapAppEngineServiceIamBinding

@typing_extensions.final
class IapAppEngineServiceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapAppEngineServiceIamMemberXCondition = IapAppEngineServiceIamMemberXCondition

@typing_extensions.final
class IapAppEngineServiceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    service: builtins.str
    @property
    def condition(self) -> global___IapAppEngineServiceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        condition: global___IapAppEngineServiceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service"]) -> None: ...

global___IapAppEngineServiceIamMember = IapAppEngineServiceIamMember

@typing_extensions.final
class IapAppEngineServiceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___IapAppEngineServiceIamPolicy = IapAppEngineServiceIamPolicy

@typing_extensions.final
class IapAppEngineVersionIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapAppEngineVersionIamBindingXCondition = IapAppEngineVersionIamBindingXCondition

@typing_extensions.final
class IapAppEngineVersionIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    service: builtins.str
    version_id: builtins.str
    @property
    def condition(self) -> global___IapAppEngineVersionIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        version_id: builtins.str = ...,
        condition: global___IapAppEngineVersionIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service", "version_id", b"version_id"]) -> None: ...

global___IapAppEngineVersionIamBinding = IapAppEngineVersionIamBinding

@typing_extensions.final
class IapAppEngineVersionIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapAppEngineVersionIamMemberXCondition = IapAppEngineVersionIamMemberXCondition

@typing_extensions.final
class IapAppEngineVersionIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    service: builtins.str
    version_id: builtins.str
    @property
    def condition(self) -> global___IapAppEngineVersionIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service: builtins.str = ...,
        version_id: builtins.str = ...,
        condition: global___IapAppEngineVersionIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service", b"service", "version_id", b"version_id"]) -> None: ...

global___IapAppEngineVersionIamMember = IapAppEngineVersionIamMember

@typing_extensions.final
class IapAppEngineVersionIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    service: builtins.str
    version_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        version_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "service", b"service", "version_id", b"version_id"]) -> None: ...

global___IapAppEngineVersionIamPolicy = IapAppEngineVersionIamPolicy

@typing_extensions.final
class IapBrandXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___IapBrandXTimeouts = IapBrandXTimeouts

@typing_extensions.final
class IapBrand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORG_INTERNAL_ONLY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SUPPORT_EMAIL_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    application_title: builtins.str
    id: builtins.str
    name: builtins.str
    org_internal_only: builtins.bool
    project: builtins.str
    support_email: builtins.str
    @property
    def timeouts(self) -> global___IapBrandXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        application_title: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        org_internal_only: builtins.bool = ...,
        project: builtins.str = ...,
        support_email: builtins.str = ...,
        timeouts: global___IapBrandXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_title", b"application_title", "id", b"id", "name", b"name", "org_internal_only", b"org_internal_only", "project", b"project", "resource_info", b"resource_info", "support_email", b"support_email", "timeouts", b"timeouts"]) -> None: ...

global___IapBrand = IapBrand

@typing_extensions.final
class IapClientXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___IapClientXTimeouts = IapClientXTimeouts

@typing_extensions.final
class IapClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRAND_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    brand: builtins.str
    client_id: builtins.str
    display_name: builtins.str
    id: builtins.str
    secret: builtins.str
    @property
    def timeouts(self) -> global___IapClientXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        brand: builtins.str = ...,
        client_id: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        secret: builtins.str = ...,
        timeouts: global___IapClientXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["brand", b"brand", "client_id", b"client_id", "display_name", b"display_name", "id", b"id", "resource_info", b"resource_info", "secret", b"secret", "timeouts", b"timeouts"]) -> None: ...

global___IapClient = IapClient

@typing_extensions.final
class IapTunnelIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapTunnelIamBindingXCondition = IapTunnelIamBindingXCondition

@typing_extensions.final
class IapTunnelIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapTunnelIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapTunnelIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapTunnelIamBinding = IapTunnelIamBinding

@typing_extensions.final
class IapTunnelIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapTunnelIamMemberXCondition = IapTunnelIamMemberXCondition

@typing_extensions.final
class IapTunnelIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapTunnelIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapTunnelIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapTunnelIamMember = IapTunnelIamMember

@typing_extensions.final
class IapTunnelIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___IapTunnelIamPolicy = IapTunnelIamPolicy

@typing_extensions.final
class IapTunnelInstanceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapTunnelInstanceIamBindingXCondition = IapTunnelInstanceIamBindingXCondition

@typing_extensions.final
class IapTunnelInstanceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___IapTunnelInstanceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___IapTunnelInstanceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___IapTunnelInstanceIamBinding = IapTunnelInstanceIamBinding

@typing_extensions.final
class IapTunnelInstanceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapTunnelInstanceIamMemberXCondition = IapTunnelInstanceIamMemberXCondition

@typing_extensions.final
class IapTunnelInstanceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___IapTunnelInstanceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___IapTunnelInstanceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance", b"instance", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___IapTunnelInstanceIamMember = IapTunnelInstanceIamMember

@typing_extensions.final
class IapTunnelInstanceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance: builtins.str
    policy_data: builtins.str
    project: builtins.str
    zone: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance", b"instance", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "zone", b"zone"]) -> None: ...

global___IapTunnelInstanceIamPolicy = IapTunnelInstanceIamPolicy

@typing_extensions.final
class IapWebBackendServiceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebBackendServiceIamBindingXCondition = IapWebBackendServiceIamBindingXCondition

@typing_extensions.final
class IapWebBackendServiceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    WEB_BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    web_backend_service: builtins.str
    @property
    def condition(self) -> global___IapWebBackendServiceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        web_backend_service: builtins.str = ...,
        condition: global___IapWebBackendServiceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "web_backend_service", b"web_backend_service"]) -> None: ...

global___IapWebBackendServiceIamBinding = IapWebBackendServiceIamBinding

@typing_extensions.final
class IapWebBackendServiceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebBackendServiceIamMemberXCondition = IapWebBackendServiceIamMemberXCondition

@typing_extensions.final
class IapWebBackendServiceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    WEB_BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    web_backend_service: builtins.str
    @property
    def condition(self) -> global___IapWebBackendServiceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        web_backend_service: builtins.str = ...,
        condition: global___IapWebBackendServiceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "web_backend_service", b"web_backend_service"]) -> None: ...

global___IapWebBackendServiceIamMember = IapWebBackendServiceIamMember

@typing_extensions.final
class IapWebBackendServiceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    WEB_BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    web_backend_service: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        web_backend_service: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "web_backend_service", b"web_backend_service"]) -> None: ...

global___IapWebBackendServiceIamPolicy = IapWebBackendServiceIamPolicy

@typing_extensions.final
class IapWebIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebIamBindingXCondition = IapWebIamBindingXCondition

@typing_extensions.final
class IapWebIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebIamBinding = IapWebIamBinding

@typing_extensions.final
class IapWebIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebIamMemberXCondition = IapWebIamMemberXCondition

@typing_extensions.final
class IapWebIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebIamMember = IapWebIamMember

@typing_extensions.final
class IapWebIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___IapWebIamPolicy = IapWebIamPolicy

@typing_extensions.final
class IapWebTypeAppEngineIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebTypeAppEngineIamBindingXCondition = IapWebTypeAppEngineIamBindingXCondition

@typing_extensions.final
class IapWebTypeAppEngineIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebTypeAppEngineIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebTypeAppEngineIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebTypeAppEngineIamBinding = IapWebTypeAppEngineIamBinding

@typing_extensions.final
class IapWebTypeAppEngineIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebTypeAppEngineIamMemberXCondition = IapWebTypeAppEngineIamMemberXCondition

@typing_extensions.final
class IapWebTypeAppEngineIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebTypeAppEngineIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebTypeAppEngineIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebTypeAppEngineIamMember = IapWebTypeAppEngineIamMember

@typing_extensions.final
class IapWebTypeAppEngineIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    app_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        app_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id", b"app_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___IapWebTypeAppEngineIamPolicy = IapWebTypeAppEngineIamPolicy

@typing_extensions.final
class IapWebTypeComputeIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebTypeComputeIamBindingXCondition = IapWebTypeComputeIamBindingXCondition

@typing_extensions.final
class IapWebTypeComputeIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebTypeComputeIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebTypeComputeIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebTypeComputeIamBinding = IapWebTypeComputeIamBinding

@typing_extensions.final
class IapWebTypeComputeIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___IapWebTypeComputeIamMemberXCondition = IapWebTypeComputeIamMemberXCondition

@typing_extensions.final
class IapWebTypeComputeIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___IapWebTypeComputeIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___IapWebTypeComputeIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___IapWebTypeComputeIamMember = IapWebTypeComputeIamMember

@typing_extensions.final
class IapWebTypeComputeIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___IapWebTypeComputeIamPolicy = IapWebTypeComputeIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeTargetGrpcProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetGrpcProxyXTimeouts = ComputeTargetGrpcProxyXTimeouts

@typing_extensions.final
class ComputeTargetGrpcProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SELF_LINK_WITH_ID_FIELD_NUMBER: builtins.int
    URL_MAP_FIELD_NUMBER: builtins.int
    VALIDATE_FOR_PROXYLESS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    self_link_with_id: builtins.str
    url_map: builtins.str
    validate_for_proxyless: builtins.bool
    @property
    def timeouts(self) -> global___ComputeTargetGrpcProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        self_link_with_id: builtins.str = ...,
        url_map: builtins.str = ...,
        validate_for_proxyless: builtins.bool = ...,
        timeouts: global___ComputeTargetGrpcProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "self_link_with_id", b"self_link_with_id", "timeouts", b"timeouts", "url_map", b"url_map", "validate_for_proxyless", b"validate_for_proxyless"]) -> None: ...

global___ComputeTargetGrpcProxy = ComputeTargetGrpcProxy

@typing_extensions.final
class ComputeTargetHttpProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetHttpProxyXTimeouts = ComputeTargetHttpProxyXTimeouts

@typing_extensions.final
class ComputeTargetHttpProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_BIND_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    URL_MAP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_bind: builtins.bool
    proxy_id: builtins.float
    self_link: builtins.str
    url_map: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetHttpProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_bind: builtins.bool = ...,
        proxy_id: builtins.float = ...,
        self_link: builtins.str = ...,
        url_map: builtins.str = ...,
        timeouts: global___ComputeTargetHttpProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_bind", b"proxy_bind", "proxy_id", b"proxy_id", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts", "url_map", b"url_map"]) -> None: ...

global___ComputeTargetHttpProxy = ComputeTargetHttpProxy

@typing_extensions.final
class ComputeTargetHttpsProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetHttpsProxyXTimeouts = ComputeTargetHttpsProxyXTimeouts

@typing_extensions.final
class ComputeTargetHttpsProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_BIND_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    QUIC_OVERRIDE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    URL_MAP_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_bind: builtins.bool
    proxy_id: builtins.float
    quic_override: builtins.str
    self_link: builtins.str
    @property
    def ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ssl_policy: builtins.str
    url_map: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetHttpsProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_bind: builtins.bool = ...,
        proxy_id: builtins.float = ...,
        quic_override: builtins.str = ...,
        self_link: builtins.str = ...,
        ssl_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        ssl_policy: builtins.str = ...,
        url_map: builtins.str = ...,
        timeouts: global___ComputeTargetHttpsProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_bind", b"proxy_bind", "proxy_id", b"proxy_id", "quic_override", b"quic_override", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_certificates", b"ssl_certificates", "ssl_policy", b"ssl_policy", "timeouts", b"timeouts", "url_map", b"url_map"]) -> None: ...

global___ComputeTargetHttpsProxy = ComputeTargetHttpsProxy

@typing_extensions.final
class ComputeTargetInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeTargetInstanceXTimeouts = ComputeTargetInstanceXTimeouts

@typing_extensions.final
class ComputeTargetInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAT_POLICY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    instance: builtins.str
    name: builtins.str
    nat_policy: builtins.str
    project: builtins.str
    self_link: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        name: builtins.str = ...,
        nat_policy: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeTargetInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "instance", b"instance", "name", b"name", "nat_policy", b"nat_policy", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeTargetInstance = ComputeTargetInstance

@typing_extensions.final
class ComputeTargetPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetPoolXTimeouts = ComputeTargetPoolXTimeouts

@typing_extensions.final
class ComputeTargetPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_POOL_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FAILOVER_RATIO_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backup_pool: builtins.str
    description: builtins.str
    failover_ratio: builtins.float
    @property
    def health_checks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    session_affinity: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetPoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backup_pool: builtins.str = ...,
        description: builtins.str = ...,
        failover_ratio: builtins.float = ...,
        health_checks: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        instances: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        session_affinity: builtins.str = ...,
        timeouts: global___ComputeTargetPoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_pool", b"backup_pool", "description", b"description", "failover_ratio", b"failover_ratio", "health_checks", b"health_checks", "id", b"id", "instances", b"instances", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "session_affinity", b"session_affinity", "timeouts", b"timeouts"]) -> None: ...

global___ComputeTargetPool = ComputeTargetPool

@typing_extensions.final
class ComputeTargetSslProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetSslProxyXTimeouts = ComputeTargetSslProxyXTimeouts

@typing_extensions.final
class ComputeTargetSslProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_header: builtins.str
    proxy_id: builtins.float
    self_link: builtins.str
    @property
    def ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ssl_policy: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetSslProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_header: builtins.str = ...,
        proxy_id: builtins.float = ...,
        self_link: builtins.str = ...,
        ssl_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        ssl_policy: builtins.str = ...,
        timeouts: global___ComputeTargetSslProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_header", b"proxy_header", "proxy_id", b"proxy_id", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_certificates", b"ssl_certificates", "ssl_policy", b"ssl_policy", "timeouts", b"timeouts"]) -> None: ...

global___ComputeTargetSslProxy = ComputeTargetSslProxy

@typing_extensions.final
class ComputeTargetTcpProxyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeTargetTcpProxyXTimeouts = ComputeTargetTcpProxyXTimeouts

@typing_extensions.final
class ComputeTargetTcpProxy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_BIND_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    PROXY_ID_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    proxy_bind: builtins.bool
    proxy_header: builtins.str
    proxy_id: builtins.float
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeTargetTcpProxyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        proxy_bind: builtins.bool = ...,
        proxy_header: builtins.str = ...,
        proxy_id: builtins.float = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeTargetTcpProxyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "proxy_bind", b"proxy_bind", "proxy_header", b"proxy_header", "proxy_id", b"proxy_id", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeTargetTcpProxy = ComputeTargetTcpProxy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestarconnections.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aws/aws_codestarconnections.proto\x12#oak9.tython.aws.codestarconnections\x1a\x13shared/shared.proto\"\xfd\x01\n\nConnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63onnection_name\x18\x02 \x01(\t\x12\x15\n\rprovider_type\x18\x03 \x01(\t\x12\x10\n\x08host_arn\x18\x04 \x01(\t\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.codestarconnections.Connection.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n\x13\x43odeStarConnections\x12\x43\n\nconnection\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.codestarconnections.Connectionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestarconnections_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONNECTION_TAGSENTRY._options = None
  _CONNECTION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTION._serialized_start=96
  _CONNECTION._serialized_end=349
  _CONNECTION_TAGSENTRY._serialized_start=306
  _CONNECTION_TAGSENTRY._serialized_end=349
  _CODESTARCONNECTIONS._serialized_start=351
  _CODESTARCONNECTIONS._serialized_end=441
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_StreamAnalytics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAMINGJOBS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_FUNCTIONS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_INPUTS_FIELD_NUMBER: builtins.int
    STREAMINGJOBS_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def streamingjobs(self) -> global___Streamingjobs: ...
    @property
    def streamingjobs_functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsFunctions]: ...
    @property
    def streamingjobs_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsInputs]: ...
    @property
    def streamingjobs_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamingjobsOutputs]: ...
    def __init__(
        self,
        *,
        streamingjobs: global___Streamingjobs | None = ...,
        streamingjobs_functions: collections.abc.Iterable[global___StreamingjobsFunctions] | None = ...,
        streamingjobs_inputs: collections.abc.Iterable[global___StreamingjobsInputs] | None = ...,
        streamingjobs_outputs: collections.abc.Iterable[global___StreamingjobsOutputs] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["streamingjobs", b"streamingjobs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["streamingjobs", b"streamingjobs", "streamingjobs_functions", b"streamingjobs_functions", "streamingjobs_inputs", b"streamingjobs_inputs", "streamingjobs_outputs", b"streamingjobs_outputs"]) -> None: ...

global___Microsoft_StreamAnalytics = Microsoft_StreamAnalytics

@typing_extensions.final
class StreamingjobsTransformations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STREAMING_UNITS_FIELD_NUMBER: builtins.int
    VALID_STREAMING_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    query: builtins.str
    streaming_units: builtins.int
    @property
    def valid_streaming_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        query: builtins.str = ...,
        streaming_units: builtins.int = ...,
        valid_streaming_units: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "query", b"query", "resource_info", b"resource_info", "streaming_units", b"streaming_units", "valid_streaming_units", b"valid_streaming_units"]) -> None: ...

global___StreamingjobsTransformations = StreamingjobsTransformations

@typing_extensions.final
class StreamingjobsOutputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATASOURCE_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    SIZE_WINDOW_FIELD_NUMBER: builtins.int
    TIME_WINDOW_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def datasource(self) -> global___OutputDataSource: ...
    @property
    def serialization(self) -> global___Serialization: ...
    size_window: builtins.float
    time_window: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        datasource: global___OutputDataSource | None = ...,
        serialization: global___Serialization | None = ...,
        size_window: builtins.float = ...,
        time_window: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "resource_info", b"resource_info", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "name", b"name", "resource_info", b"resource_info", "serialization", b"serialization", "size_window", b"size_window", "time_window", b"time_window"]) -> None: ...

global___StreamingjobsOutputs = StreamingjobsOutputs

@typing_extensions.final
class StreamingjobsInputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def compression(self) -> global___Compression: ...
    partition_key: builtins.str
    @property
    def serialization(self) -> global___Serialization: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        compression: global___Compression | None = ...,
        partition_key: builtins.str = ...,
        serialization: global___Serialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compression", b"compression", "resource_info", b"resource_info", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compression", b"compression", "name", b"name", "partition_key", b"partition_key", "resource_info", b"resource_info", "serialization", b"serialization"]) -> None: ...

global___StreamingjobsInputs = StreamingjobsInputs

@typing_extensions.final
class StreamingjobsFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BINDING_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def binding(self) -> global___FunctionBinding: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionInput]: ...
    @property
    def output(self) -> global___FunctionOutput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        binding: global___FunctionBinding | None = ...,
        inputs: collections.abc.Iterable[global___FunctionInput] | None = ...,
        output: global___FunctionOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binding", b"binding", "output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "inputs", b"inputs", "name", b"name", "output", b"output", "resource_info", b"resource_info"]) -> None: ...

global___StreamingjobsFunctions = StreamingjobsFunctions

@typing_extensions.final
class Streamingjobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    CONTENT_STORAGE_POLICY_FIELD_NUMBER: builtins.int
    DATA_LOCALE_FIELD_NUMBER: builtins.int
    EVENTS_LATE_ARRIVAL_MAX_DELAY_IN_SECONDS_FIELD_NUMBER: builtins.int
    EVENTS_OUT_OF_ORDER_MAX_DELAY_IN_SECONDS_FIELD_NUMBER: builtins.int
    EVENTS_OUT_OF_ORDER_POLICY_FIELD_NUMBER: builtins.int
    EXTERNALS_FIELD_NUMBER: builtins.int
    FUNCTIONS_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    JOB_STORAGE_ACCOUNT_FIELD_NUMBER: builtins.int
    JOB_TYPE_FIELD_NUMBER: builtins.int
    OUTPUT_ERROR_POLICY_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_START_MODE_FIELD_NUMBER: builtins.int
    OUTPUT_START_TIME_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___Identity: ...
    location: builtins.str
    name: builtins.str
    @property
    def cluster(self) -> global___ClusterInfo: ...
    compatibility_level: builtins.str
    content_storage_policy: builtins.str
    data_locale: builtins.str
    events_late_arrival_max_delay_in_seconds: builtins.int
    events_out_of_order_max_delay_in_seconds: builtins.int
    events_out_of_order_policy: builtins.str
    @property
    def externals(self) -> global___External: ...
    @property
    def functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Function]: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Input]: ...
    @property
    def job_storage_account(self) -> global___JobStorageAccount: ...
    job_type: builtins.str
    output_error_policy: builtins.str
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Output]: ...
    output_start_mode: builtins.str
    output_start_time: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def transformation(self) -> global___Transformation: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___Identity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        cluster: global___ClusterInfo | None = ...,
        compatibility_level: builtins.str = ...,
        content_storage_policy: builtins.str = ...,
        data_locale: builtins.str = ...,
        events_late_arrival_max_delay_in_seconds: builtins.int = ...,
        events_out_of_order_max_delay_in_seconds: builtins.int = ...,
        events_out_of_order_policy: builtins.str = ...,
        externals: global___External | None = ...,
        functions: collections.abc.Iterable[global___Function] | None = ...,
        inputs: collections.abc.Iterable[global___Input] | None = ...,
        job_storage_account: global___JobStorageAccount | None = ...,
        job_type: builtins.str = ...,
        output_error_policy: builtins.str = ...,
        outputs: collections.abc.Iterable[global___Output] | None = ...,
        output_start_mode: builtins.str = ...,
        output_start_time: builtins.str = ...,
        sku: global___Sku | None = ...,
        transformation: global___Transformation | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "externals", b"externals", "identity", b"identity", "job_storage_account", b"job_storage_account", "resource_info", b"resource_info", "sku", b"sku", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "compatibility_level", b"compatibility_level", "content_storage_policy", b"content_storage_policy", "data_locale", b"data_locale", "events_late_arrival_max_delay_in_seconds", b"events_late_arrival_max_delay_in_seconds", "events_out_of_order_max_delay_in_seconds", b"events_out_of_order_max_delay_in_seconds", "events_out_of_order_policy", b"events_out_of_order_policy", "externals", b"externals", "functions", b"functions", "identity", b"identity", "inputs", b"inputs", "job_storage_account", b"job_storage_account", "job_type", b"job_type", "location", b"location", "name", b"name", "output_error_policy", b"output_error_policy", "output_start_mode", b"output_start_mode", "output_start_time", b"output_start_time", "outputs", b"outputs", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "transformation", b"transformation"]) -> None: ...

global___Streamingjobs = Streamingjobs

@typing_extensions.final
class Transformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    STREAMING_UNITS_FIELD_NUMBER: builtins.int
    VALID_STREAMING_UNITS_FIELD_NUMBER: builtins.int
    name: builtins.str
    query: builtins.str
    streaming_units: builtins.int
    @property
    def valid_streaming_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        query: builtins.str = ...,
        streaming_units: builtins.int = ...,
        valid_streaming_units: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "query", b"query", "streaming_units", b"streaming_units", "valid_streaming_units", b"valid_streaming_units"]) -> None: ...

global___Transformation = Transformation

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class Output(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DATASOURCE_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    SIZE_WINDOW_FIELD_NUMBER: builtins.int
    TIME_WINDOW_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def datasource(self) -> global___OutputDataSource: ...
    @property
    def serialization(self) -> global___Serialization: ...
    size_window: builtins.float
    time_window: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        datasource: global___OutputDataSource | None = ...,
        serialization: global___Serialization | None = ...,
        size_window: builtins.float = ...,
        time_window: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["datasource", b"datasource", "name", b"name", "serialization", b"serialization", "size_window", b"size_window", "time_window", b"time_window"]) -> None: ...

global___Output = Output

@typing_extensions.final
class OutputDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___OutputDataSource = OutputDataSource

@typing_extensions.final
class JobStorageAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_MODE_FIELD_NUMBER: builtins.int
    account_key: builtins.str
    account_name: builtins.str
    authentication_mode: builtins.str
    def __init__(
        self,
        *,
        account_key: builtins.str = ...,
        account_name: builtins.str = ...,
        authentication_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_key", b"account_key", "account_name", b"account_name", "authentication_mode", b"authentication_mode"]) -> None: ...

global___JobStorageAccount = JobStorageAccount

@typing_extensions.final
class Input(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    SERIALIZATION_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def compression(self) -> global___Compression: ...
    partition_key: builtins.str
    @property
    def serialization(self) -> global___Serialization: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        compression: global___Compression | None = ...,
        partition_key: builtins.str = ...,
        serialization: global___Serialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compression", b"compression", "serialization", b"serialization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compression", b"compression", "name", b"name", "partition_key", b"partition_key", "serialization", b"serialization"]) -> None: ...

global___Input = Input

@typing_extensions.final
class Serialization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Serialization = Serialization

@typing_extensions.final
class Compression(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___Compression = Compression

@typing_extensions.final
class Function(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BINDING_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def binding(self) -> global___FunctionBinding: ...
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionInput]: ...
    @property
    def output(self) -> global___FunctionOutput: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        binding: global___FunctionBinding | None = ...,
        inputs: collections.abc.Iterable[global___FunctionInput] | None = ...,
        output: global___FunctionOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binding", b"binding", "output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binding", b"binding", "inputs", b"inputs", "name", b"name", "output", b"output"]) -> None: ...

global___Function = Function

@typing_extensions.final
class FunctionOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TYPE_FIELD_NUMBER: builtins.int
    data_type: builtins.str
    def __init__(
        self,
        *,
        data_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type", b"data_type"]) -> None: ...

global___FunctionOutput = FunctionOutput

@typing_extensions.final
class FunctionInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TYPE_FIELD_NUMBER: builtins.int
    IS_CONFIGURATION_PARAMETER_FIELD_NUMBER: builtins.int
    data_type: builtins.str
    is_configuration_parameter: builtins.bool
    def __init__(
        self,
        *,
        data_type: builtins.str = ...,
        is_configuration_parameter: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type", b"data_type", "is_configuration_parameter", b"is_configuration_parameter"]) -> None: ...

global___FunctionInput = FunctionInput

@typing_extensions.final
class FunctionBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    name: builtins.str
    api_key: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "name", b"name"]) -> None: ...

global___FunctionBinding = FunctionBinding

@typing_extensions.final
class External(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_FIELD_NUMBER: builtins.int
    container: builtins.str
    path: builtins.str
    @property
    def storage_account(self) -> global___StorageAccount: ...
    def __init__(
        self,
        *,
        container: builtins.str = ...,
        path: builtins.str = ...,
        storage_account: global___StorageAccount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["storage_account", b"storage_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container", b"container", "path", b"path", "storage_account", b"storage_account"]) -> None: ...

global___External = External

@typing_extensions.final
class StorageAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    account_key: builtins.str
    account_name: builtins.str
    def __init__(
        self,
        *,
        account_key: builtins.str = ...,
        account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_key", b"account_key", "account_name", b"account_name"]) -> None: ...

global___StorageAccount = StorageAccount

@typing_extensions.final
class ClusterInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ClusterInfo = ClusterInfo

@typing_extensions.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___Identity = Identity



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_eventschemas.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_eventschemas.proto\x12\x1coak9.tython.aws.eventschemas\x1a\x13shared/shared.proto\"j\n\x13\x44iscovererTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xaf\x01\n\nDiscoverer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nsource_arn\x18\x03 \x01(\t\x12?\n\x04tags\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.eventschemas.DiscovererTagsEntry\"\x83\x02\n\x0c\x45ventSchemas\x12<\n\ndiscoverer\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.eventschemas.Discoverer\x12\x38\n\x08registry\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.eventschemas.Registry\x12\x45\n\x0fregistry_policy\x18\x03 \x03(\x0b\x32,.oak9.tython.aws.eventschemas.RegistryPolicy\x12\x34\n\x06schema\x18\x04 \x03(\x0b\x32$.oak9.tython.aws.eventschemas.Schema\"h\n\x11RegistryTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xae\x01\n\x08Registry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\rregistry_name\x18\x03 \x01(\t\x12=\n\x04tags\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.eventschemas.RegistryTagsEntry\"\xee\x01\n\x0eRegistryPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x06policy\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.eventschemas.RegistryPolicy.PolicyEntry\x12\x15\n\rregistry_name\x18\x03 \x01(\t\x12\x13\n\x0brevision_id\x18\x04 \x01(\t\x1a-\n\x0bPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x0fSchemaTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xde\x01\n\x06Schema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x15\n\rregistry_name\x18\x05 \x01(\t\x12\x13\n\x0bschema_name\x18\x06 \x01(\t\x12;\n\x04tags\x18\x07 \x03(\x0b\x32-.oak9.tython.aws.eventschemas.SchemaTagsEntryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_eventschemas_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTRYPOLICY_POLICYENTRY._options = None
  _REGISTRYPOLICY_POLICYENTRY._serialized_options = b'8\001'
  _DISCOVERERTAGSENTRY._serialized_start=81
  _DISCOVERERTAGSENTRY._serialized_end=187
  _DISCOVERER._serialized_start=190
  _DISCOVERER._serialized_end=365
  _EVENTSCHEMAS._serialized_start=368
  _EVENTSCHEMAS._serialized_end=627
  _REGISTRYTAGSENTRY._serialized_start=629
  _REGISTRYTAGSENTRY._serialized_end=733
  _REGISTRY._serialized_start=736
  _REGISTRY._serialized_end=910
  _REGISTRYPOLICY._serialized_start=913
  _REGISTRYPOLICY._serialized_end=1151
  _REGISTRYPOLICY_POLICYENTRY._serialized_start=1106
  _REGISTRYPOLICY_POLICYENTRY._serialized_end=1151
  _SCHEMATAGSENTRY._serialized_start=1153
  _SCHEMATAGSENTRY._serialized_end=1255
  _SCHEMA._serialized_start=1258
  _SCHEMA._serialized_end=1480
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PriorityClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GLOBAL_DEFAULT_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    PREEMPTION_POLICY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    description: builtins.str
    global_default: builtins.bool
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    preemption_policy: builtins.str
    value: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        description: builtins.str = ...,
        global_default: builtins.bool = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        preemption_policy: builtins.str = ...,
        value: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "description", b"description", "global_default", b"global_default", "kind", b"kind", "metadata", b"metadata", "preemption_policy", b"preemption_policy", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___PriorityClass = PriorityClass

@typing_extensions.final
class PriorityClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PriorityClass]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PriorityClass] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PriorityClassList = PriorityClassList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codegurureviewer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_codegurureviewer.proto\x12 oak9.tython.aws.codegurureviewer\x1a\x13shared/shared.proto\"\x93\x01\n\x15RepositoryAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x16\n\x0e\x63onnection_arn\x18\x05 \x01(\t\"k\n\x10\x43odeGuruReviewer\x12W\n\x16repository_association\x18\x01 \x03(\x0b\x32\x37.oak9.tython.aws.codegurureviewer.RepositoryAssociationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codegurureviewer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORYASSOCIATION._serialized_start=90
  _REPOSITORYASSOCIATION._serialized_end=237
  _CODEGURUREVIEWER._serialized_start=239
  _CODEGURUREVIEWER._serialized_end=346
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MemberMemberFabricConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    admin_username: builtins.str
    admin_password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        admin_username: builtins.str = ...,
        admin_password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_password", b"admin_password", "admin_username", b"admin_username", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberFabricConfiguration = MemberMemberFabricConfiguration

@typing_extensions.final
class MemberMemberFrameworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_FABRIC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def member_fabric_configuration(self) -> global___MemberMemberFabricConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_fabric_configuration: global___MemberMemberFabricConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_fabric_configuration", b"member_fabric_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_fabric_configuration", b"member_fabric_configuration", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberFrameworkConfiguration = MemberMemberFrameworkConfiguration

@typing_extensions.final
class MemberMemberConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBER_FRAMEWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def member_framework_configuration(self) -> global___MemberMemberFrameworkConfiguration: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        member_framework_configuration: global___MemberMemberFrameworkConfiguration | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_framework_configuration", b"member_framework_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "member_framework_configuration", b"member_framework_configuration", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___MemberMemberConfiguration = MemberMemberConfiguration

@typing_extensions.final
class MemberApprovalThresholdPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    THRESHOLD_COMPARATOR_FIELD_NUMBER: builtins.int
    THRESHOLD_PERCENTAGE_FIELD_NUMBER: builtins.int
    PROPOSAL_DURATION_IN_HOURS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    threshold_comparator: builtins.str
    threshold_percentage: builtins.int
    proposal_duration_in_hours: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        threshold_comparator: builtins.str = ...,
        threshold_percentage: builtins.int = ...,
        proposal_duration_in_hours: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_duration_in_hours", b"proposal_duration_in_hours", "resource_info", b"resource_info", "threshold_comparator", b"threshold_comparator", "threshold_percentage", b"threshold_percentage"]) -> None: ...

global___MemberApprovalThresholdPolicy = MemberApprovalThresholdPolicy

@typing_extensions.final
class MemberVotingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPROVAL_THRESHOLD_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def approval_threshold_policy(self) -> global___MemberApprovalThresholdPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        approval_threshold_policy: global___MemberApprovalThresholdPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_threshold_policy", b"approval_threshold_policy", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_threshold_policy", b"approval_threshold_policy", "resource_info", b"resource_info"]) -> None: ...

global___MemberVotingPolicy = MemberVotingPolicy

@typing_extensions.final
class MemberNetworkFabricConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    edition: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        edition: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["edition", b"edition", "resource_info", b"resource_info"]) -> None: ...

global___MemberNetworkFabricConfiguration = MemberNetworkFabricConfiguration

@typing_extensions.final
class MemberNetworkFrameworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NETWORK_FABRIC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def network_fabric_configuration(self) -> global___MemberNetworkFabricConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        network_fabric_configuration: global___MemberNetworkFabricConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_fabric_configuration", b"network_fabric_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_fabric_configuration", b"network_fabric_configuration", "resource_info", b"resource_info"]) -> None: ...

global___MemberNetworkFrameworkConfiguration = MemberNetworkFrameworkConfiguration

@typing_extensions.final
class MemberNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FRAMEWORK_VERSION_FIELD_NUMBER: builtins.int
    VOTING_POLICY_FIELD_NUMBER: builtins.int
    FRAMEWORK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FRAMEWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    framework_version: builtins.str
    @property
    def voting_policy(self) -> global___MemberVotingPolicy: ...
    framework: builtins.str
    name: builtins.str
    @property
    def network_framework_configuration(self) -> global___MemberNetworkFrameworkConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        framework_version: builtins.str = ...,
        voting_policy: global___MemberVotingPolicy | None = ...,
        framework: builtins.str = ...,
        name: builtins.str = ...,
        network_framework_configuration: global___MemberNetworkFrameworkConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_framework_configuration", b"network_framework_configuration", "resource_info", b"resource_info", "voting_policy", b"voting_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "framework", b"framework", "framework_version", b"framework_version", "name", b"name", "network_framework_configuration", b"network_framework_configuration", "resource_info", b"resource_info", "voting_policy", b"voting_policy"]) -> None: ...

global___MemberNetworkConfiguration = MemberNetworkConfiguration

@typing_extensions.final
class Member(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    INVITATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def member_configuration(self) -> global___MemberMemberConfiguration: ...
    @property
    def network_configuration(self) -> global___MemberNetworkConfiguration: ...
    network_id: builtins.str
    invitation_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_configuration: global___MemberMemberConfiguration | None = ...,
        network_configuration: global___MemberNetworkConfiguration | None = ...,
        network_id: builtins.str = ...,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["member_configuration", b"member_configuration", "network_configuration", b"network_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id", "member_configuration", b"member_configuration", "network_configuration", b"network_configuration", "network_id", b"network_id", "resource_info", b"resource_info"]) -> None: ...

global___Member = Member

@typing_extensions.final
class ManagedBlockchain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBER_FIELD_NUMBER: builtins.int
    NODE_FIELD_NUMBER: builtins.int
    @property
    def member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Member]: ...
    @property
    def node(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Node]: ...
    def __init__(
        self,
        *,
        member: collections.abc.Iterable[global___Member] | None = ...,
        node: collections.abc.Iterable[global___Node] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["member", b"member", "node", b"node"]) -> None: ...

global___ManagedBlockchain = ManagedBlockchain

@typing_extensions.final
class NodeNodeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    availability_zone: builtins.str
    instance_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        availability_zone: builtins.str = ...,
        instance_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone", b"availability_zone", "instance_type", b"instance_type", "resource_info", b"resource_info"]) -> None: ...

global___NodeNodeConfiguration = NodeNodeConfiguration

@typing_extensions.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MEMBER_ID_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    NODE_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    member_id: builtins.str
    network_id: builtins.str
    @property
    def node_configuration(self) -> global___NodeNodeConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        member_id: builtins.str = ...,
        network_id: builtins.str = ...,
        node_configuration: global___NodeNodeConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_configuration", b"node_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["member_id", b"member_id", "network_id", b"network_id", "node_configuration", b"node_configuration", "resource_info", b"resource_info"]) -> None: ...

global___Node = Node
